@@ -2,13 +2,14 @@ from __future__ import annotations
 from AIH_SDK.AIHClient import AIHClient
 import AIH_SDK.AIHExceptions as AIHE
 from collections import defaultdict
+from numpyencoder import NumpyEncoder
 import json
 import pandas as pd
 import numpy as np
 
 class Object:
     
-    def __init__(self, new=False):
+    def __init__(self):
         self.value = dict()
         self._api = ''
         self._endpoint = ''
@@ -16,23 +17,39 @@ class Object:
         
     
     def get_value(self, key:str, index:int=None):
-        
+        """
+        get_value gets the value for the input key. 
+        Key gets split at '__' to access nested keys.
+        If index is not specified it will return the values for the key for all elements in the list.
+        If self.value is a dict, index is ignored and will just return the value for the key.
+
+        IN: key (str)   - The key to use for accessing the desired value. '__' is used to access nested values.
+            index (int) - The index to get if self.value is a list.
+
+        OUT: The value for the specified key.
+             If self.value is a dict it will return the value.
+             If self.value is a list and index is provided it will return the value.
+             If self.value is a list and index is not provided it will return a list of the values.   
+        """
+
+        keys = key.split('__')
+
         if type(self.value) == dict:
             value = self.value
-            for k in key.split('__'):
+            for k in keys:
                 value = value[k]
         
         elif type(self.value) == list:
             value = self.value
             if index is not None:
                 value = value[index]
-                for k in key.split('__'):
+                for k in keys:
                     value = value[k]
         
             else:
                 values = []
                 for value in self.value:
-                    for k in key.split('__'):
+                    for k in keys:
                         value = value[k]
                     values.append(value)
                 value = values
@@ -40,6 +57,47 @@ class Object:
         return value
 
 
+    def set_value(self, key:str, value, index:int=None):
+        """
+        set_value sets the value for the input key. 
+        Key gets split at '__' to access nested keys.
+        If index is not specified it will set the values for the key for all elements in the self.value.
+        If self.value is a dict, index is ignored and will just set the value for the key.
+
+        IN: key (str)   - The key to use for accessing the desired value. '__' is used to access nested values.
+            index (int) - The index to set if self.value is a list.
+
+        OUT: self
+        """
+
+        keys = key.split('__')
+        
+        if type(self.value) == dict:
+            _value = self.value
+            for k in keys[:-1]:
+                _value = _value[k]
+            
+            _value[keys[-1]] = value
+                
+        elif type(self.value) == list:
+            _value = self.value
+            if index is not None:
+                _value = _value[index]
+                for k in keys[:-1]:
+                    _value = _value[k]
+                    
+                _value[keys[-1]] = value
+                
+            else:
+                for _value in self.value:
+                    for k in keys[:-1]:
+                        _value = _value[k]
+                    
+                    _value[keys[-1]] = value
+        
+        return self
+
+
     def put(self):
         """
         To put the updates that have been made to the object.
@@ -47,10 +105,10 @@ class Object:
         
         if type(self.value) == list:
             for val in self.value:
-                self._client.put(self._api, self._endpoint, val)
+                self._client._put(self._api, self._endpoint, val)
                 
         elif type(self.value) == dict:
-            self._client.put(self._api, self._endpoint, self.value)
+            self._client._put(self._api, self._endpoint, self.value)
 
         return self
 
@@ -61,7 +119,7 @@ class Object:
         """
         if type(self.value) == list:
             for i, val in enumerate(self.value):
-                response = self._client.post(self._api, self._endpoint, val)
+                response = self._client._post(self._api, self._endpoint, val)
 
                 # Sets the id for the posted value
                 if 'id' in response:
@@ -71,7 +129,7 @@ class Object:
                     self.value[i]['id'] = response[key]['id']
                 
         elif type(self.value) == dict:
-            response = self._client.post(self._api, self._endpoint, self.value)
+            response = self._client._post(self._api, self._endpoint, self.value)
 
             # Sets the id for the posted value
             if 'id' in response:
@@ -92,10 +150,10 @@ class Object:
         
         if type(id_to_delete_) == list:
             for id_to_delete in id_to_delete_:
-                self._client.delete(self._api, self._endpoint, id_to_delete)
+                self._client._delete(self._api, self._endpoint, id_to_delete)
         
         elif type(id_to_delete_) == str:
-            self._client.delete(self._api, self._endpoint, id_to_delete_)
+            self._client._delete(self._api, self._endpoint, id_to_delete_)
         
         self.value = None
         
@@ -320,7 +378,7 @@ class Object:
                 temp = temp[k]
             temp[ks[-1]] = value
             
-        return dict(json.loads(json.dumps(result)))
+        return dict(json.loads(json.dumps(result, cls=NumpyEncoder)))
             
     
     def _implode(self, df, col, column_group=None):
