@@ -1,12 +1,10 @@
-from AIH_SDK.v2.v2Object import v2Object
+from AIH_SDK.v2.DataUpload.DataUploadObject import DataUploadObject
 
 
-class DataType(v2Object):
+class DataType(DataUploadObject):
     
     def __init__(self):
         super().__init__()
-        
-        self._api = 'du'
         self._endpoint = 'DataTypes'
 
     
