@@ -2,6 +2,7 @@ from AIH_SDK.v2.DataUpload.DataUploadObject import DataUploadObject
 from AIH_SDK.AIHExceptions import AIHException
 from PIL import Image
 import io
+import pickle
 
 
 class File(DataUploadObject):
@@ -47,29 +48,40 @@ class File(DataUploadObject):
         if type(self.value) == dict:
             content = self._client._download_file(self.value["id"])
 
-            # If file is an image, set content to PIL.Image
             if self.value['name'].split('.')[-1] in self._image_extensions:
+                # If file is an image, set content to PIL.Image
                 content = Image.open(io.BytesIO(content))
 
+            elif self.value['name'].split('.')[-1] == 'pickle':
+                # If file is a pickle, load it the type it represents
+                content = pickle.loads(content)
+
             yield content
 
         elif type(self.value) == list:
             for val in self.value:
                 content = self._client._download_file(val["id"])
                 
-                # If file is an image, set content to PIL.Image
                 if val['name'].split('.')[-1].lower() in self._image_extensions:
+                    # If file is an image, set content to PIL.Image
                     content = Image.open(io.BytesIO(content))
 
+                elif self.value['name'].split('.')[-1] == 'pickle':
+                    # If file is a pickle, load it the type it represents
+                    content = pickle.loads(content)
+
                 yield content
     
 
     def upload(self, file, datatype_id:str, name:str, exif:bytes=None):
         """
         To post the updates that have been made.
-        IN: file     - The that should be uploaded
-            name     - The name of the file that should be uploaded. Should contain the file extention
-            exif     - Exif dictionary that is converted to bytes. Is used to set the metadata.
+        IN: file              - The that should be uploaded.
+            datatype_id (str) - The guid of the datatype that that the file should be upload as.
+            name (str)        - The name of the file that should be uploaded. Should contain the file extention.
+            exif (dict)       - Exif dictionary that is converted to bytes. Is used to set the metadata.
+
+        OUT: self
         """
         
         fileextension = name.split('.')[-1]
@@ -88,4 +100,21 @@ class File(DataUploadObject):
         response_json = self._client._upload_file(datatype_id, _file, name)
         self.value = response_json
         
-        return self
\ No newline at end of file
+        return self
+    
+
+    def upload_from_data(self, data:dict, datatype_id:str, name:str):
+        """
+        upload_from_data creates a file containing the data and uploads it.
+
+        IN: data              - The data to create a file from and upload. Can e.g. be dict, list, strings etc.
+            datatype_id (str) - The guid of the datatype that that the file should be upload as.
+            name (str)        - The name of the file that should be uploaded. Should contain the file extention.
+
+        OUR: self
+        """
+        f = io.BytesIO()
+        pickle.dump(data, f)
+        f.seek(0)
+
+        return self.upload(f, datatype_id, name)
